@@ -10,12 +10,12 @@
 #define __CVSSERVICE_STUB__
 
 #include <dcopstub.h>
-#include <qstringlist.h>
-#include <dcopref.h>
 #include <dcopobject.h>
+#include <dcopref.h>
+#include <qstringlist.h>
 
 
-class CvsService_stub : virtual public DCOPStub
+class KDE_EXPORT CvsService_stub : virtual public DCOPStub
 {
 public:
     CvsService_stub( const QCString& app, const QCString& id );
@@ -26,6 +26,7 @@ public:
     virtual DCOPRef annotate( const QString& fileName, const QString& revision );
     virtual DCOPRef checkout( const QString& workingDir, const QString& repository, const QString& module, const QString& tag, bool pruneDirs );
     virtual DCOPRef checkout( const QString& workingDir, const QString& repository, const QString& module, const QString& tag, bool pruneDirs, const QString& alias, bool exportOnly );
+    virtual DCOPRef checkout( const QString& workingDir, const QString& repository, const QString& module, const QString& tag, bool pruneDirs, const QString& alias, bool exportOnly, bool recursive );
     virtual DCOPRef commit( const QStringList& files, const QString& commitMessage, bool recursive );
     virtual DCOPRef createRepository( const QString& repository );
     virtual DCOPRef createTag( const QStringList& files, const QString& tag, bool branch, bool force );
@@ -49,6 +50,7 @@ public:
     virtual DCOPRef moduleList( const QString& repository );
     virtual DCOPRef remove( const QStringList& files, bool recursive );
     virtual DCOPRef removeWatch( const QStringList& files, int events );
+    virtual DCOPRef rlog( const QString& repository, const QString& module, bool recursive );
     virtual DCOPRef simulateUpdate( const QStringList& files, bool recursive, bool createDirs, bool pruneDirs );
     virtual DCOPRef status( const QStringList& files, bool recursive, bool tagInfo );
     virtual DCOPRef unedit( const QStringList& files );
