@@ -18,8 +18,19 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
+  In addition, as a special exception, the copyright holders give
+  permission to link the code of this program with any edition of
+  the Qt library by Trolltech AS, Norway (or with modified versions
+  of Qt that use the same license as Qt), and distribute linked
+  combinations including the two.  You must obey the GNU General
+  Public License in all respects for all of the code used other than
+  Qt. If you modify this file, you may extend this exception to
+  your version of the file, but you are not obligated to do so.  If
+  you do not wish to do so, delete this exception statement from
+  your version.
+ 
 **************************************************************************** */
 #ifndef CATALOG_H
 #define CATALOG_H
@@ -33,6 +44,8 @@
 
 #include <qptrlist.h>
 #include <qvaluevector.h>
+#include <kdemacros.h>
+#include <kstandarddirs.h>
 
 class KDataTool;
 class QString;
@@ -43,8 +56,6 @@ class QFile;
 class KDataTool;
 class KURL;
 
-#define KBABEL_DEFAULTPROJECT	"kbabel.defaultproject"
-
 namespace KBabel
 {
 
@@ -69,7 +80,7 @@ class CatalogPrivate;
 */
 struct DocPosition
 {
-	DocPosition( ) : offset(0), item(0), form(0) { }
+	DocPosition( ) : offset(0), part(UndefPart), item(0), form(0) { }
 	uint offset;
 	
 	Part part;
@@ -96,7 +107,7 @@ struct DiffEntry
 * @short Class, that represents a translation catalog(po-file)
 * @author Matthias Kiefer <matthias.kiefer@gmx.de>
 */
-class Catalog : public QObject
+class KDE_EXPORT Catalog : public QObject
 {
     Q_OBJECT
 
@@ -120,7 +131,7 @@ public:
    * @param name   unique name for this object
    * @param configFile configuration file to read config from
    */
-   Catalog(QObject* parent=0, const char* name=0, QString projectFile = KBABEL_DEFAULTPROJECT);
+   Catalog(QObject* parent=0, const char* name=0, QString projectFile = QString() );
 
    /**
    * Deprecated. A copy constructor. Do not use since each Catalog registers
@@ -129,6 +140,14 @@ public:
    Catalog(const Catalog&);
    virtual ~Catalog();
 
+   /**
+   * Get the message context for a given message.
+   *
+   * @param index  index of the requested message
+   * @return       context for the given message
+   */
+   QString msgctxt(uint index) const;
+   
    /**
    * Get list of texts for a given message in original language. Each entry in the list
    * represents a single singular/plural form.
@@ -166,8 +185,9 @@ public:
    *
    * @param index  index of the requested message
    * @return       context information found in the message comment
+   * @deprecated
    */
-   QString context(uint index) const;
+   QString context(uint index) const KDE_DEPRECATED;
 
    /**
    * Get the header for the current file.
@@ -367,6 +387,9 @@ public:
    uint numberOfFuzzies() const;
    /** @return current number of untranslated entries */
    uint numberOfUntranslated() const;
+   
+   /** returns the number of words total, in fuzzy and in untranslated messages */
+   void wordCount (uint &total, uint &fuzzy, uint &untranslated) const;
 
    bool hasFuzzyInFront(uint index) const;
    bool hasFuzzyAfterwards(uint index) const;
